@@ -4,7 +4,7 @@
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
-//krazy:excludeall=contractions
+// krazy:excludeall=contractions
 
 #include "addresseetest.h"
 #include "kcontacts/addressee.h"
@@ -18,7 +18,7 @@ void AddresseeTest::emptyTest()
     QVERIFY(addressee.isEmpty());
 
     KContacts::Addressee addresseeWithMail;
-    addresseeWithMail.insertEmail(QStringLiteral("foo@bar.org"));
+    addresseeWithMail.addEmail(QStringLiteral("foo@bar.org"));
     QVERIFY(!addresseeWithMail.isEmpty());
 }
 
@@ -65,7 +65,7 @@ void AddresseeTest::storeTest()
     addressee.setOrganization(QStringLiteral("Scottland Yard"));
     addressee.setNote(QStringLiteral("Don't cross black deads way..."));
     addressee.setProductId(QStringLiteral("ProductId45"));
-    addressee.setRevision(QDateTime(QDate(1982, 9, 15)));
+    addressee.setRevision(QDateTime(QDate(1982, 9, 15).startOfDay()));
     addressee.setSortString(QStringLiteral("Name"));
     KContacts::ResourceLocatorUrl url;
     url.setUrl(QUrl(QStringLiteral("www.scottlandyard.info")));
@@ -109,7 +109,7 @@ void AddresseeTest::storeTest()
     QVERIFY(addressee.organization() == QLatin1String("Scottland Yard"));
     QVERIFY(addressee.note() == QLatin1String("Don't cross black deads way..."));
     QVERIFY(addressee.productId() == QLatin1String("ProductId45"));
-    QVERIFY(addressee.revision() == QDateTime(QDate(1982, 9, 15)));
+    QVERIFY(addressee.revision() == QDateTime(QDate(1982, 9, 15).startOfDay()));
     QVERIFY(addressee.sortString() == QLatin1String("Name"));
     QVERIFY(addressee.url() == url);
     QVERIFY(addressee.secrecy() == KContacts::Secrecy(KContacts::Secrecy::Public));
@@ -126,7 +126,8 @@ void AddresseeTest::storeTest()
 
 void AddresseeTest::equalsTest()
 {
-    KContacts::Addressee addressee1, addressee2;
+    KContacts::Addressee addressee1;
+    KContacts::Addressee addressee2;
 
     KContacts::Picture logo(QStringLiteral("http://scottlandyard.info/pics/logo.png"));
     KContacts::Picture photo(QStringLiteral("http://scottlandyard.info/~sinclair/photo.png"));
@@ -153,7 +154,7 @@ void AddresseeTest::equalsTest()
     addressee1.setPrefix(QStringLiteral("Sir"));
     addressee1.setSuffix(QStringLiteral("II"));
     addressee1.setNickName(QStringLiteral("ghosthunter"));
-    addressee1.setBirthday(QDateTime(QDate(1982, 7, 19)));
+    addressee1.setBirthday(QDateTime(QDate(1982, 7, 19).startOfDay()));
     addressee1.setMailer(QStringLiteral("mutt"));
     addressee1.setTimeZone(KContacts::TimeZone(2));
     addressee1.setGeo(KContacts::Geo(42, 23));
@@ -162,7 +163,7 @@ void AddresseeTest::equalsTest()
     addressee1.setOrganization(QStringLiteral("Scottland Yard"));
     addressee1.setNote(QStringLiteral("Don't cross black deads way..."));
     addressee1.setProductId(QStringLiteral("ProductId45"));
-    addressee1.setRevision(QDateTime(QDate(1982, 9, 15)));
+    addressee1.setRevision(QDateTime(QDate(1982, 9, 15).startOfDay()));
     addressee1.setSortString(QStringLiteral("Name"));
     KContacts::ResourceLocatorUrl url;
     url.setUrl(QUrl(QStringLiteral("www.scottlandyard.info")));
@@ -186,7 +187,7 @@ void AddresseeTest::equalsTest()
     addressee2.setPrefix(QStringLiteral("Sir"));
     addressee2.setSuffix(QStringLiteral("II"));
     addressee2.setNickName(QStringLiteral("ghosthunter"));
-    addressee2.setBirthday(QDateTime(QDate(1982, 7, 19)));
+    addressee2.setBirthday(QDateTime(QDate(1982, 7, 19).startOfDay()));
     addressee2.setMailer(QStringLiteral("mutt"));
     addressee2.setTimeZone(KContacts::TimeZone(2));
     addressee2.setGeo(KContacts::Geo(42, 23));
@@ -195,7 +196,7 @@ void AddresseeTest::equalsTest()
     addressee2.setOrganization(QStringLiteral("Scottland Yard"));
     addressee2.setNote(QStringLiteral("Don't cross black deads way..."));
     addressee2.setProductId(QStringLiteral("ProductId45"));
-    addressee2.setRevision(QDateTime(QDate(1982, 9, 15)));
+    addressee2.setRevision(QDateTime(QDate(1982, 9, 15).startOfDay()));
     addressee2.setSortString(QStringLiteral("Name"));
     addressee2.setUrl(url);
     addressee2.setSecrecy(KContacts::Secrecy(KContacts::Secrecy::Public));
@@ -213,7 +214,8 @@ void AddresseeTest::equalsTest()
 
 void AddresseeTest::differsTest()
 {
-    KContacts::Addressee addressee1, addressee2;
+    KContacts::Addressee addressee1;
+    KContacts::Addressee addressee2;
 
     addressee1.setNameFromString(QStringLiteral("John Sinclair"));
     addressee2.setNameFromString(QStringLiteral("Suko"));
@@ -223,7 +225,8 @@ void AddresseeTest::differsTest()
 
 void AddresseeTest::assignmentTest()
 {
-    KContacts::Addressee addressee1, addressee2;
+    KContacts::Addressee addressee1;
+    KContacts::Addressee addressee2;
 
     KContacts::Picture logo(QStringLiteral("http://scottlandyard.info/pics/logo.png"));
     KContacts::Picture photo(QStringLiteral("http://scottlandyard.info/~sinclair/photo.png"));
@@ -250,7 +253,7 @@ void AddresseeTest::assignmentTest()
     addressee1.setPrefix(QStringLiteral("Sir"));
     addressee1.setSuffix(QStringLiteral("II"));
     addressee1.setNickName(QStringLiteral("ghosthunter"));
-    addressee1.setBirthday(QDateTime(QDate(1982, 7, 19)));
+    addressee1.setBirthday(QDateTime(QDate(1982, 7, 19).startOfDay()));
     addressee1.setMailer(QStringLiteral("mutt"));
     addressee1.setTimeZone(KContacts::TimeZone(2));
     addressee1.setGeo(KContacts::Geo(42, 23));
@@ -259,7 +262,7 @@ void AddresseeTest::assignmentTest()
     addressee1.setOrganization(QStringLiteral("Scottland Yard"));
     addressee1.setNote(QStringLiteral("Don't cross black deads way..."));
     addressee1.setProductId(QStringLiteral("ProductId45"));
-    addressee1.setRevision(QDateTime(QDate(1982, 9, 15)));
+    addressee1.setRevision(QDateTime(QDate(1982, 9, 15).startOfDay()));
     addressee1.setSortString(QStringLiteral("Name"));
     KContacts::ResourceLocatorUrl url;
     url.setUrl(QUrl(QStringLiteral("www.scottlandyard.info")));
@@ -281,7 +284,8 @@ void AddresseeTest::assignmentTest()
 
 void AddresseeTest::serializeTest()
 {
-    KContacts::Addressee addressee1, addressee2;
+    KContacts::Addressee addressee1;
+    KContacts::Addressee addressee2;
 
     KContacts::Picture logo(QStringLiteral("http://scottlandyard.info/pics/logo.png"));
     KContacts::Picture photo(QStringLiteral("http://scottlandyard.info/~sinclair/photo.png"));
@@ -297,8 +301,7 @@ void AddresseeTest::serializeTest()
     categories << QStringLiteral("Helper") << QStringLiteral("Friend");
 
     QStringList customs;
-    customs << QStringLiteral("FirstApp-FirstKey:FirstValue")
-            << QStringLiteral("SecondApp-SecondKey:SecondValue")
+    customs << QStringLiteral("FirstApp-FirstKey:FirstValue") << QStringLiteral("SecondApp-SecondKey:SecondValue")
             << QStringLiteral("ThirdApp-ThirdKey:ThirdValue");
 
     addressee1.setUid(QStringLiteral("My uid"));
@@ -310,7 +313,7 @@ void AddresseeTest::serializeTest()
     addressee1.setPrefix(QStringLiteral("Sir"));
     addressee1.setSuffix(QStringLiteral("II"));
     addressee1.setNickName(QStringLiteral("ghosthunter"));
-    addressee1.setBirthday(QDateTime(QDate(1982, 7, 19)));
+    addressee1.setBirthday(QDateTime(QDate(1982, 7, 19).startOfDay()));
     addressee1.setMailer(QStringLiteral("mutt"));
     addressee1.setTimeZone(KContacts::TimeZone(2));
     addressee1.setGeo(KContacts::Geo(42, 23));
@@ -319,7 +322,7 @@ void AddresseeTest::serializeTest()
     addressee1.setOrganization(QStringLiteral("Scottland Yard"));
     addressee1.setNote(QStringLiteral("Don't cross black deads way..."));
     addressee1.setProductId(QStringLiteral("ProductId45"));
-    addressee1.setRevision(QDateTime(QDate(1982, 9, 15)));
+    addressee1.setRevision(QDateTime(QDate(1982, 9, 15).startOfDay()));
     addressee1.setSortString(QStringLiteral("Name"));
     KContacts::ResourceLocatorUrl url;
     url.setUrl(QUrl(QStringLiteral("www.scottlandyard.info")));
@@ -352,8 +355,7 @@ void AddresseeTest::fullEmailTest()
     emails << QStringLiteral("foo@bar.com");
     a.setEmails(emails);
     a.setFormattedName(QStringLiteral("firstname \"nickname\" lastname"));
-    QCOMPARE(a.fullEmail(),
-             QStringLiteral("\"firstname \\\"nickname\\\" lastname\" <foo@bar.com>"));
+    QCOMPARE(a.fullEmail(), QStringLiteral("\"firstname \\\"nickname\\\" lastname\" <foo@bar.com>"));
 }
 
 void AddresseeTest::nameFromStringTest()
@@ -378,7 +380,7 @@ void AddresseeTest::customFieldsTest()
     QCOMPARE(a.custom(QStringLiteral("MyApp"), QStringLiteral("MyKey")), QStringLiteral("MyValue"));
 
     a.insertCustom(QStringLiteral("MyApp"), QStringLiteral("MyKey"), QStringLiteral("YourValue"));
-    QCOMPARE(a.customs().count(), 1);   // still one, we overwrite...
+    QCOMPARE(a.customs().count(), 1); // still one, we overwrite...
     QCOMPARE(a.custom(QStringLiteral("MyApp"), QStringLiteral("MyKey")), QStringLiteral("YourValue"));
 
     // test query non-existing app/key
@@ -398,7 +400,7 @@ void AddresseeTest::customFieldsTest()
     QCOMPARE(a.custom(QStringLiteral("MyApp"), QStringLiteral("AnotherKey")), QStringLiteral("OtherValue"));
     QCOMPARE(a.custom(QStringLiteral("MyApp"), QStringLiteral("MyKey")), QStringLiteral("YourValue"));
 
-#if 0 //Order is not defined now as we use a QHash
+#if 0 // Order is not defined now as we use a QHash
     // test customs
     QCOMPARE(a.customs().at(0), QStringLiteral("MyApp-MyKey:YourValue"));
     QCOMPARE(a.customs().at(1), QStringLiteral("MyApp-AnotherKey:OtherValue"));
@@ -421,8 +423,8 @@ void AddresseeTest::customFieldsTest()
     c.insertCustom(QStringLiteral("ThisApp"), QStringLiteral("ShouldNotBe"), QStringLiteral("There"));
     QCOMPARE(c.customs().count(), 1);
 
-    const QStringList testData = QStringList() << QStringLiteral("FirstApp-FirstKey:FirstValue")
-                                               << QStringLiteral("SecondApp-SecondKey:SecondValue")
+    const QStringList testData = QStringList() << QStringLiteral("FirstApp-FirstKey:FirstValue") //
+                                               << QStringLiteral("SecondApp-SecondKey:SecondValue") //
                                                << QStringLiteral("ThirdApp-ThirdKey:ThirdValue");
 
     c.setCustoms(testData);
@@ -464,3 +466,5 @@ void AddresseeTest::parseEmailAddress()
     QCOMPARE(parsedEmail, email);
     QCOMPARE(parsedName, name);
 }
+
+#include "moc_addresseetest.cpp"
